@@ -16,7 +16,7 @@
 #
 
 from ai.h2o.sparkling.ml.models.H2OMOJOModel import H2OMOJOModelFactory
-from ai.h2o.sparkling.H2ODataFrameConverters import H2ODataFrameConverters
+from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
 
 
 class H2OAutoMLExtras:
@@ -25,7 +25,7 @@ class H2OAutoMLExtras:
         if len(extraColumns) == 1 and isinstance(extraColumns[0], list):
             extraColumns = extraColumns[0]
         leaderboard_java = self._java_obj.getLeaderboard(extraColumns)
-        return H2ODataFrameConverters.scalaToPythonDataFrame(leaderboard_java)
+        return H2OTypeConverters.scalaToPythonDataFrame(leaderboard_java)
 
     def getAllModels(self):
         javaModels = self._java_obj.getAllModels()
